@@ -158,6 +158,7 @@ def create_project(project_name):
     create_server_file(project_name, directories['server'], 'main', False)
     create_server_file(project_name, directories['server'], 'test_server_post', False)
     create_server_file(project_name, directories['server'], 'pool', False)
+    create_server_file(project_name, directories['server'], 'token_generator', False)
     create_server_file(project_name, directories['server'], '__init__', False)
     # create_init_file(directories['server'] + '/__init__.py', 'from server.main import app\nfrom server.pool import InstancePool')
     # create_tester_file(project_name, directories['trainer'], 'trainer')
@@ -250,6 +251,7 @@ def replace_in_template_and_create_file(project_name, folder, pipelineType, data
 
     data = data.replace('generatedClassName', classNameForBaseObject)
     data = data.replace('generatedClass', className)
+    data = data.replace('original_project_name', project_name)
     data = data.replace('generatedProjectName', project_name_no_underscore)
     data = data.replace('generatedDirectory', currentDir)
     data = data.replace('generatedBaseDir', currentBaseDir)
