@@ -11,7 +11,8 @@ from dsframework.base.common import functions
 class ZIDS_SharedArtifacts():
 
     def __init__(self) -> None:
-        self.base_dir = os.path.dirname(os.getcwd())
+        self.base_dir = os.getcwd()
+        self.parent_dir = os.path.dirname(os.getcwd())
         self.load_config_json()
         self.load_vocabs()
         self.load_artifacts()
@@ -61,8 +62,8 @@ class ZIDS_SharedArtifacts():
 
     def load_tensorflow(self, path, name):
         raise NotImplementedError
-        # with open(path) as json_file:
-        #     setattr(self, name, tf.keras.models.load_model(path))
+        # with open(path) as tensorflow_file:
+        #     setattr(self, name, tf.keras.models.load_model(tensorflow_file))
 
     def get(self, key, default=None):
         if key in self.__dict__:
